@@ -165,7 +165,7 @@
     ("Shinza"             . "$(B$7$s$6(B")
     ("Misashima"          . "$(BH~:4Eg(B")
     ("Uonumaky-Dry"-A       . "$(B5{>B5VNM(B")
-    ("Uonuma-ky-Dry"-A      . "$(B5{>B5VNM(B")
+    ("Uonuma-Ky-Dry"-A      . "$(B5{>B5VNM(B")
     ("Muikamachi"         . "$(BO;F|D.(B")
     ("Nishi--Dtsu"-A         . "$(B@>BgDE(B")))
 
